aboutsummaryrefslogtreecommitdiffstats
path: root/src/gwin
diff options
context:
space:
mode:
authorinmarket <andrewh@inmarket.com.au>2018-02-27 17:44:21 +1000
committerinmarket <andrewh@inmarket.com.au>2018-02-27 17:44:21 +1000
commitf265924396167729e8d9fb36a0383263f36c1270 (patch)
tree28843eb24b18999cf0217ecb0fe935f133901066 /src/gwin
parent14786e97b618b8bc2a0ff1c732d45288fe550e33 (diff)
downloaduGFX-f265924396167729e8d9fb36a0383263f36c1270.tar.gz
uGFX-f265924396167729e8d9fb36a0383263f36c1270.tar.bz2
uGFX-f265924396167729e8d9fb36a0383263f36c1270.zip
First set of V3 macro changes
Diffstat (limited to 'src/gwin')
-rw-r--r--src/gwin/gwin.h12
-rw-r--r--src/gwin/gwin_button.h18
-rw-r--r--src/gwin/gwin_checkbox.h4
-rw-r--r--src/gwin/gwin_console.c6
-rw-r--r--src/gwin/gwin_console.h6
-rw-r--r--src/gwin/gwin_container.h4
-rw-r--r--src/gwin/gwin_frame.h6
-rw-r--r--src/gwin/gwin_gl3d.h4
-rw-r--r--src/gwin/gwin_graph.h4
-rw-r--r--src/gwin/gwin_image.h12
-rw-r--r--src/gwin/gwin_keyboard.h4
-rw-r--r--src/gwin/gwin_label.h8
-rw-r--r--src/gwin/gwin_list.h8
-rw-r--r--src/gwin/gwin_options.h162
-rw-r--r--src/gwin/gwin_progressbar.h6
-rw-r--r--src/gwin/gwin_radio.h4
-rw-r--r--src/gwin/gwin_rules.h56
-rw-r--r--src/gwin/gwin_slider.h6
-rw-r--r--src/gwin/gwin_tabset.h6
-rw-r--r--src/gwin/gwin_textedit.h8
-rw-r--r--src/gwin/gwin_widget.h8
21 files changed, 176 insertions, 176 deletions
diff --git a/src/gwin/gwin.h b/src/gwin/gwin.h
index c3d18c31..1331a874 100644
--- a/src/gwin/gwin.h
+++ b/src/gwin/gwin.h
@@ -18,7 +18,7 @@
* will have it's own properties such as colors as well as
* it's own drawing origin.
*
- * @pre GFX_USE_GWIN must be set to TRUE in your gfxconf.h
+ * @pre GFX_USE_GWIN must be set to GFXON in your gfxconf.h
* @{
*/
@@ -493,7 +493,7 @@ extern "C" {
/**
* @brief Minimize, Maximize or Restore a window
- * @pre GWIN_NEED_WINDOWMANAGER must be TRUE
+ * @pre GWIN_NEED_WINDOWMANAGER must be GFXON
*
* @param[in] gh The window
* @param[in] minmax The new minimized/maximized state
@@ -514,7 +514,7 @@ extern "C" {
/**
* @brief Get the Minimized/Maximized state of a window
- * @pre GWIN_NEED_WINDOWMANAGER must be TRUE
+ * @pre GWIN_NEED_WINDOWMANAGER must be GFXON
*
* @param[in] gh The window
*
@@ -526,7 +526,7 @@ extern "C" {
/**
* @brief Raise a window to the top of the z-order
- * @pre GWIN_NEED_WINDOWMANAGER must be TRUE
+ * @pre GWIN_NEED_WINDOWMANAGER must be GFXON
*
* @param[in] gh The window
*
@@ -565,7 +565,7 @@ extern "C" {
* way every flash period (GWIN_FLASHING_PERIOD). How its appearance
* changes depends on the draw for each window/widget.
*
- * @pre Requires GWIN_NEED_FLASHING to be TRUE
+ * @pre Requires GWIN_NEED_FLASHING to be GFXON
*
* @api
*/
@@ -724,7 +724,7 @@ extern "C" {
* @note Uses the current foreground color to draw the inner circle
* @note Uses the current background color to draw the outer circle
* @note May leave GDISP clipping to this window's dimensions
- * @pre GDISP_NEED_DUALCIRCLE must be TRUE in your gfxconf.h
+ * @pre GDISP_NEED_DUALCIRCLE must be GFXON in your gfxconf.h
*
* @param[in] gh The window handle
* @param[in] x,y The center of the circle
diff --git a/src/gwin/gwin_button.h b/src/gwin/gwin_button.h
index 11af82e0..77751c04 100644
--- a/src/gwin/gwin_button.h
+++ b/src/gwin/gwin_button.h
@@ -18,8 +18,8 @@
* and check for different meta states such as: PRESSED, CLICKED,
* RELEASED etc.
*
- * @pre GFX_USE_GWIN must be set to TRUE in your gfxconf.h
- * @pre GWIN_NEED_BUTTON must be set to TRUE in your gfxconf.h
+ * @pre GFX_USE_GWIN must be set to GFXON in your gfxconf.h
+ * @pre GWIN_NEED_BUTTON must be set to GFXON in your gfxconf.h
* @{
*/
@@ -129,7 +129,7 @@ void gwinButtonDraw_Normal(GWidgetObject *gw, void *param);
* @param[in] gw The widget object (must be a button object)
* @param[in] param A parameter passed in from the user. Ignored by this function.
*
- * @pre GDISP_NEED_ARC must be set to TRUE
+ * @pre GDISP_NEED_ARC must be set to GFXON
*
* @api
*/
@@ -143,7 +143,7 @@ void gwinButtonDraw_Normal(GWidgetObject *gw, void *param);
* @param[in] gw The widget object (must be a button object)
* @param[in] param A parameter passed in from the user. Ignored by this function.
*
- * @pre GDISP_NEED_ELLIPSE must be set to TRUE
+ * @pre GDISP_NEED_ELLIPSE must be set to GFXON
*
* @api
*/
@@ -157,7 +157,7 @@ void gwinButtonDraw_Normal(GWidgetObject *gw, void *param);
* @param[in] gw The widget object (must be a button object)
* @param[in] param A parameter passed in from the user. Ignored by this function.
*
- * @pre GDISP_NEED_CONVEX_POLYGON must be set to TRUE
+ * @pre GDISP_NEED_CONVEX_POLYGON must be set to GFXON
*
* @api
*/
@@ -169,7 +169,7 @@ void gwinButtonDraw_Normal(GWidgetObject *gw, void *param);
* @param[in] gw The widget object (must be a button object)
* @param[in] param A parameter passed in from the user. Ignored by this function.
*
- * @pre GDISP_NEED_CONVEX_POLYGON must be set to TRUE
+ * @pre GDISP_NEED_CONVEX_POLYGON must be set to GFXON
*
* @api
*/
@@ -181,7 +181,7 @@ void gwinButtonDraw_Normal(GWidgetObject *gw, void *param);
* @param[in] gw The widget object (must be a button object)
* @param[in] param A parameter passed in from the user. Ignored by this function.
*
- * @pre GDISP_NEED_CONVEX_POLYGON must be set to TRUE
+ * @pre GDISP_NEED_CONVEX_POLYGON must be set to GFXON
*
* @api
*/
@@ -193,7 +193,7 @@ void gwinButtonDraw_Normal(GWidgetObject *gw, void *param);
* @param[in] gw The widget object (must be a button object)
* @param[in] param A parameter passed in from the user. Ignored by this function.
*
- * @pre GDISP_NEED_CONVEX_POLYGON must be set to TRUE
+ * @pre GDISP_NEED_CONVEX_POLYGON must be set to GFXON
*
* @api
*/
@@ -214,7 +214,7 @@ void gwinButtonDraw_Normal(GWidgetObject *gw, void *param);
* No checking is done to compare the size of the button to the size of the image.
* Note text is drawn on top of the image.
*
- * @pre GDISP_NEED_IMAGE must be set to TRUE
+ * @pre GDISP_NEED_IMAGE must be set to GFXON
*
* @api
*/
diff --git a/src/gwin/gwin_checkbox.h b/src/gwin/gwin_checkbox.h
index b704dffe..b4a1c811 100644
--- a/src/gwin/gwin_checkbox.h
+++ b/src/gwin/gwin_checkbox.h
@@ -16,8 +16,8 @@
*
* @details GWIN allows it to easily create a group of checkbox buttons.
*
- * @pre GFX_USE_GWIN must be set to TRUE in your gfxconf.h
- * @pre GWIN_NEED_CHECKBOX must be set to TRUE in your gfxconf.h
+ * @pre GFX_USE_GWIN must be set to GFXON in your gfxconf.h
+ * @pre GWIN_NEED_CHECKBOX must be set to GFXON in your gfxconf.h
* @{
*/
diff --git a/src/gwin/gwin_console.c b/src/gwin/gwin_console.c
index ad5152f0..71d0905a 100644
--- a/src/gwin/gwin_console.c
+++ b/src/gwin/gwin_console.c
@@ -18,9 +18,9 @@
#include "gwin_class.h"
-#define GWIN_CONSOLE_USE_CLEAR_LINES TRUE // Clear each line before using it
-#define GWIN_CONSOLE_USE_FILLED_CHARS FALSE // Use filled characters instead of drawn characters
-#define GWIN_CONSOLE_BUFFER_SCROLLING TRUE // Use the history buffer to scroll when it is available
+#define GWIN_CONSOLE_USE_CLEAR_LINES GFXON // Clear each line before using it
+#define GWIN_CONSOLE_USE_FILLED_CHARS GFXOFF // Use filled characters instead of drawn characters
+#define GWIN_CONSOLE_BUFFER_SCROLLING GFXON // Use the history buffer to scroll when it is available
// Our control flags
#define GCONSOLE_FLG_NOSTORE (GWIN_FIRST_CONTROL_FLAG<<0)
diff --git a/src/gwin/gwin_console.h b/src/gwin/gwin_console.h
index 3da9df12..6b0f3fe6 100644
--- a/src/gwin/gwin_console.h
+++ b/src/gwin/gwin_console.h
@@ -17,8 +17,8 @@
* @details GWIN allows it to create a console/terminal like window.
* You can simply use chprintf() to print to the terminal.
*
- * @pre GFX_USE_GWIN must be set to TRUE in your gfxconf.h
- * @pre GWIN_NEED_CONSOLE must be set to TRUE in your gfxconf.h
+ * @pre GFX_USE_GWIN must be set to GFXON in your gfxconf.h
+ * @pre GWIN_NEED_CONSOLE must be set to GFXON in your gfxconf.h
*
* @{
*/
@@ -99,7 +99,7 @@ GHandle gwinGConsoleCreate(GDisplay *g, GConsoleObject *gc, const GWindowInit *p
#if GWIN_CONSOLE_USE_HISTORY
/**
* @brief Assign a buffer to keep track of the content while the widget is invisible.
- * @pre GWIN_CONSOLE_USE_HISTORY must be set to TRUE in your gfxconf.h
+ * @pre GWIN_CONSOLE_USE_HISTORY must be set to GFXON in your gfxconf.h
*
* @param[in] gh The window handle (must be a console window)
* @param[in] onoff If TRUE a buffer is allocated to maintain console text
diff --git a/src/gwin/gwin_container.h b/src/gwin/gwin_container.h
index ce2ab4bd..9020c73e 100644
--- a/src/gwin/gwin_container.h
+++ b/src/gwin/gwin_container.h
@@ -16,7 +16,7 @@
* @details A Container is a GWindow that supports child windows. It is also
* a widget in its own right and therefore can accept user input directly.
*
- * @pre GFX_USE_GWIN and GWIN_NEED_CONTAINERS must be set to TRUE in your gfxconf.h
+ * @pre GFX_USE_GWIN and GWIN_NEED_CONTAINERS must be set to GFXON in your gfxconf.h
* @{
*/
@@ -173,7 +173,7 @@ void gwinContainerDraw_Transparent(GWidgetObject *gw, void *param);
* @note The image must be already opened before calling @p gwinSetCustomDraw(). The handle is passed as the parameter
* to this function.
*
- * @pre GDISP_NEED_IMAGE must be set to TRUE
+ * @pre GDISP_NEED_IMAGE must be set to GFXON
*
* @api
*/
diff --git a/src/gwin/gwin_frame.h b/src/gwin/gwin_frame.h
index f39d3df6..06488321 100644
--- a/src/gwin/gwin_frame.h
+++ b/src/gwin/gwin_frame.h
@@ -17,8 +17,8 @@
* @details A frame is a rectangular window that can have optional border as well as buttons to
* close, maximize and minimize it. The main purpose of this widget is to contain children.
*
- * @pre GFX_USE_GWIN must be set to TRUE in your gfxconf.h
- * @pre GWIN_NEED_FRAME must be set to TRUE in your gfxconf.h
+ * @pre GFX_USE_GWIN must be set to GFXON in your gfxconf.h
+ * @pre GWIN_NEED_FRAME must be set to GFXON in your gfxconf.h
* @{
*/
@@ -130,7 +130,7 @@ void gwinFrameDraw_Transparent(GWidgetObject *gw, void *param);
* @note The image must be already opened before calling @p gwinSetCustomDraw(). The handle is passed as the parameter
* to this function.
*
- * @pre GDISP_NEED_IMAGE must be set to TRUE
+ * @pre GDISP_NEED_IMAGE must be set to GFXON
*
* @api
*/
diff --git a/src/gwin/gwin_gl3d.h b/src/gwin/gwin_gl3d.h
index 52330029..fd1220b0 100644
--- a/src/gwin/gwin_gl3d.h
+++ b/src/gwin/gwin_gl3d.h
@@ -16,8 +16,8 @@
*
* @details 3D GWIN window based on OpenGL (or more exactly Tiny GL)
*
- * @pre GFX_USE_GWIN must be set to TRUE in your gfxconf.h
- * @pre GWIN_NEED_GL3D must be set to TRUE in your gfxconf.h
+ * @pre GFX_USE_GWIN must be set to GFXON in your gfxconf.h
+ * @pre GWIN_NEED_GL3D must be set to GFXON in your gfxconf.h
*
* @{
*/
diff --git a/src/gwin/gwin_graph.h b/src/gwin/gwin_graph.h
index 3f4c3181..61b411a2 100644
--- a/src/gwin/gwin_graph.h
+++ b/src/gwin/gwin_graph.h
@@ -16,8 +16,8 @@
*
* @details GWIN allows it to easily draw graphs.
*
- * @pre GFX_USE_GWIN must be set to TRUE in your gfxconf.h
- * @pre GWIN_NEED_GRAPH must be set to TRUE in your gfxconf.h
+ * @pre GFX_USE_GWIN must be set to GFXON in your gfxconf.h
+ * @pre GWIN_NEED_GRAPH must be set to GFXON in your gfxconf.h
*
* @{
*/
diff --git a/src/gwin/gwin_image.h b/src/gwin/gwin_image.h
index d3874f65..b45629ee 100644
--- a/src/gwin/gwin_image.h
+++ b/src/gwin/gwin_image.h
@@ -17,10 +17,10 @@
* @details GWIN allos it to create an image widget. The widget
* takes no user input.
*
- * @pre GFX_USE_GDISP must be set to TRUE in your gfxconf.h
- * @pre GFX_USE_GWIN must be set to TRUE in your gfxconf.h
- * @pre GDISP_NEED_IMAGE must be set to TRUE in your gfxconf.h
- * @pre GWIN_NEED_IMAGE must be set to TRUE in your gfxconf.h
+ * @pre GFX_USE_GDISP must be set to GFXON in your gfxconf.h
+ * @pre GFX_USE_GWIN must be set to GFXON in your gfxconf.h
+ * @pre GDISP_NEED_IMAGE must be set to GFXON in your gfxconf.h
+ * @pre GWIN_NEED_IMAGE must be set to GFXON in your gfxconf.h
* @pre At least one image type must be enabled in your gfxconf.h
*
* @{
@@ -86,7 +86,7 @@ bool_t gwinImageOpenGFile(GHandle gh, GFILE *f);
/**
* @brief Sets the input routines that support reading the image from memory
* in RAM or flash.
- * @pre GFILE_NEED_MEMFS must be TRUE
+ * @pre GFILE_NEED_MEMFS must be GFXON
* @return TRUE if the IO open function succeeds
*
* @param[in] gh The widget (must be an image widget)
@@ -99,7 +99,7 @@ bool_t gwinImageOpenGFile(GHandle gh, GFILE *f);
/**
* @brief Sets the input routines that support reading the image from a BaseFileStream (eg. an SD-Card).
* @return TRUE if the IO open function succeeds
- * @pre GFILE_NEED_CHIBIOSFS and GFX_USE_OS_CHIBIOS must be TRUE
+ * @pre GFILE_NEED_CHIBIOSFS and GFX_USE_OS_CHIBIOS must be GFXON
*
* @param[in] gh The widget (must be an image widget)
* @param[in] streamPtr A pointer to the (open) BaseFileStream object.
diff --git a/src/gwin/gwin_keyboard.h b/src/gwin/gwin_keyboard.h
index 98780485..68bf215f 100644
--- a/src/gwin/gwin_keyboard.h
+++ b/src/gwin/gwin_keyboard.h
@@ -18,8 +18,8 @@
* and check for different meta states such as: PRESSED, CLICKED,
* RELEASED etc.
*
- * @pre GFX_USE_GWIN must be set to TRUE in your gfxconf.h
- * @pre GWIN_NEED_BUTTON must be set to TRUE in your gfxconf.h
+ * @pre GFX_USE_GWIN must be set to GFXON in your gfxconf.h
+ * @pre GWIN_NEED_BUTTON must be set to GFXON in your gfxconf.h
* @{
*/
diff --git a/src/gwin/gwin_label.h b/src/gwin/gwin_label.h
index 1e8ba53e..66c4d97d 100644
--- a/src/gwin/gwin_label.h
+++ b/src/gwin/gwin_label.h
@@ -19,10 +19,10 @@
* dimensions of the label will change every time the text is changed
* through gwinSetText().
*
- * @pre GFX_USE_GDISP must be set to TRUE in your gfxconf.h
- * @pre GFX_USE_GWIN must be set to TRUE in your gfxconf.h
- * @pre GDISP_NEED_TEXT must be set to TRUE in your gfxconf.h
- * @pre GWIN_NEED_LABEL must be set to TRUE in your gfxconf.h
+ * @pre GFX_USE_GDISP must be set to GFXON in your gfxconf.h
+ * @pre GFX_USE_GWIN must be set to GFXON in your gfxconf.h
+ * @pre GDISP_NEED_TEXT must be set to GFXON in your gfxconf.h
+ * @pre GWIN_NEED_LABEL must be set to GFXON in your gfxconf.h
* @pre The fonts you want to use must be enabled in your gfxconf.h
*
* @{
diff --git a/src/gwin/gwin_list.h b/src/gwin/gwin_list.h
index 81db7c34..ad64be75 100644
--- a/src/gwin/gwin_list.h
+++ b/src/gwin/gwin_list.h
@@ -16,10 +16,10 @@
*
* @details Provides advanced features such as multi-selection, smooth scrolling and item icons.
*
- * @pre GFX_USE_GDISP must be set to TRUE in your gfxconf.h
- * @pre GFX_USE_GWIN must be set to TRUE in your gfxconf.h
- * @pre GDISP_NEED_TEXT must be set to TRUE in your gfxconf.h
- * @pre GWIN_NEED_LIST must be set to TRUE in your gfxconf.h
+ * @pre GFX_USE_GDISP must be set to GFXON in your gfxconf.h
+ * @pre GFX_USE_GWIN must be set to GFXON in your gfxconf.h
+ * @pre GDISP_NEED_TEXT must be set to GFXON in your gfxconf.h
+ * @pre GWIN_NEED_LIST must be set to GFXON in your gfxconf.h
* @pre The font you want to use must be enabled in your gfxconf.h
*
* @{
diff --git a/src/gwin/gwin_options.h b/src/gwin/gwin_options.h
index 6bf59d2a..06b7da5c 100644
--- a/src/gwin/gwin_options.h
+++ b/src/gwin/gwin_options.h
@@ -25,24 +25,24 @@
*/
/**
* @brief Should window manager support be included
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
*/
#ifndef GWIN_NEED_WINDOWMANAGER
- #define GWIN_NEED_WINDOWMANAGER FALSE
+ #define GWIN_NEED_WINDOWMANAGER GFXOFF
#endif
/**
* @brief Should the widget hierarchy be included. This provides parent-child features.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
*/
#ifndef GWIN_NEED_CONTAINERS
- #define GWIN_NEED_CONTAINERS FALSE
+ #define GWIN_NEED_CONTAINERS GFXOFF
#endif
/**
* @brief Should widget functions be included. Needed for any widget (eg Buttons, Sliders etc)
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
*/
#ifndef GWIN_NEED_WIDGET
- #define GWIN_NEED_WIDGET FALSE
+ #define GWIN_NEED_WIDGET GFXOFF
#endif
/**
* @brief The width of the rectangle that highlights a widget that is focused
@@ -53,115 +53,115 @@
#endif
/**
* @brief Should the simple container be included.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
*/
#ifndef GWIN_NEED_CONTAINER
- #define GWIN_NEED_CONTAINER FALSE
+ #define GWIN_NEED_CONTAINER GFXOFF
#endif
/**
* @brief Should the frame widget be included.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
*/
#ifndef GWIN_NEED_FRAME
- #define GWIN_NEED_FRAME FALSE
+ #define GWIN_NEED_FRAME GFXOFF
#endif
/**
* @brief Should console functions be included.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
*/
#ifndef GWIN_NEED_CONSOLE
- #define GWIN_NEED_CONSOLE FALSE
+ #define GWIN_NEED_CONSOLE GFXOFF
#endif
/**
* @brief Should graph functions be included.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
*/
#ifndef GWIN_NEED_GRAPH
- #define GWIN_NEED_GRAPH FALSE
+ #define GWIN_NEED_GRAPH GFXOFF
#endif
/**
* @brief Should gl3d functions be included.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
*/
#ifndef GWIN_NEED_GL3D
- #define GWIN_NEED_GL3D FALSE
+ #define GWIN_NEED_GL3D GFXOFF
#endif
/**
* @brief Should button functions be included.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
*/
#ifndef GWIN_NEED_BUTTON
- #define GWIN_NEED_BUTTON FALSE
+ #define GWIN_NEED_BUTTON GFXOFF
#endif
/**
* @brief Should progressbar functions be included.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
*/
#ifndef GWIN_NEED_PROGRESSBAR
- #define GWIN_NEED_PROGRESSBAR FALSE
+ #define GWIN_NEED_PROGRESSBAR GFXOFF
#endif
/**
* @brief Should slider functions be included.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
*/
#ifndef GWIN_NEED_SLIDER
- #define GWIN_NEED_SLIDER FALSE
+ #define GWIN_NEED_SLIDER GFXOFF
#endif
/**
* @brief Should checkbox functions be included.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
*/
#ifndef GWIN_NEED_CHECKBOX
- #define GWIN_NEED_CHECKBOX FALSE
+ #define GWIN_NEED_CHECKBOX GFXOFF
#endif
/**
* @brief Should image functions be included.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
*/
#ifndef GWIN_NEED_IMAGE
- #define GWIN_NEED_IMAGE FALSE
+ #define GWIN_NEED_IMAGE GFXOFF
#endif
/**
* @brief Should label functions be included.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
*/
#ifndef GWIN_NEED_LABEL
- #define GWIN_NEED_LABEL FALSE
+ #define GWIN_NEED_LABEL GFXOFF
#endif
/**
* @brief Should radio button functions be included.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
*/
#ifndef GWIN_NEED_RADIO
- #define GWIN_NEED_RADIO FALSE
+ #define GWIN_NEED_RADIO GFXOFF
#endif
/**
* @brief Should list widget functions be included.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
*/
#ifndef GWIN_NEED_LIST
- #define GWIN_NEED_LIST FALSE
+ #define GWIN_NEED_LIST GFXOFF
#endif
/**
* @brief Should tabset functions be included.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
*/
#ifndef GWIN_NEED_TABSET
- #define GWIN_NEED_TABSET FALSE
+ #define GWIN_NEED_TABSET GFXOFF
#endif
/**
* @brief Should the virtual keyboard be included.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
*/
#ifndef GWIN_NEED_KEYBOARD
- #define GWIN_NEED_KEYBOARD FALSE
+ #define GWIN_NEED_KEYBOARD GFXOFF
#endif
/**
* @brief Should the textedit widget be included.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
*/
#ifndef GWIN_NEED_TEXTEDIT
- #define GWIN_NEED_TEXTEDIT FALSE
+ #define GWIN_NEED_TEXTEDIT GFXOFF
#endif
/**
* @}
@@ -171,59 +171,59 @@
*/
/**
* @brief Add a tag to each widget
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
* @note Adds a tag member to each widget. Any events created include this tag.
* The enables switch based application logic to detect the event source.
*/
#ifndef GWIN_WIDGET_TAGS
- #define GWIN_WIDGET_TAGS FALSE
+ #define GWIN_WIDGET_TAGS GFXOFF
#endif
/**
* @brief Use flat styling for controls rather than a 3D look
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
* @note This may appear better on color-restricted displays
* @note Flat styling is less graphics and cpu intensive (marginally) than the default 3D look.
*/
#ifndef GWIN_FLAT_STYLING
- #define GWIN_FLAT_STYLING FALSE
+ #define GWIN_FLAT_STYLING GFXOFF
#endif
/**
* @brief Don't use a timer for redrawing windows
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
* @note Normally windows and widgets are redrawn on a timer. Setting this
* option causes them to be redrawn immediately. Note that this can
* cause extended blocking times on events and saves little code.
- * @note If GWIN_NEED_WINDOWMANAGER is FALSE then this setting is ignored
+ * @note If GWIN_NEED_WINDOWMANAGER is GFXOFF then this setting is ignored
* as redrawing always occurs immediately.
*/
#ifndef GWIN_REDRAW_IMMEDIATE
- #define GWIN_REDRAW_IMMEDIATE FALSE
+ #define GWIN_REDRAW_IMMEDIATE GFXOFF
#endif
/**
* @brief Redraw all windows in a single operation
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
* @note Windows are normally redraw one per gtimer cycle.
* Setting this option causes all windows to be redrawn in
* a single gtimer cycle. Note that this can
* cause extended blocking times on the timer thread but may
* speed up redraw slightly.
- * @note This is only relevant if GWIN_REDRAW_IMMEDIATE is FALSE.
+ * @note This is only relevant if GWIN_REDRAW_IMMEDIATE is GFXOFF.
* Everything always gets redrawn in a single operation if
- * GWIN_REDRAW_IMMEDIATE is TRUE.
+ * GWIN_REDRAW_IMMEDIATE is GFXON.
*/
#ifndef GWIN_REDRAW_SINGLEOP
- #define GWIN_REDRAW_SINGLEOP FALSE
+ #define GWIN_REDRAW_SINGLEOP GFXOFF
#endif
/**
* @brief Buttons should not insist the mouse is over the button on mouse release
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
*/
#ifndef GWIN_BUTTON_LAZY_RELEASE
- #define GWIN_BUTTON_LAZY_RELEASE FALSE
+ #define GWIN_BUTTON_LAZY_RELEASE GFXOFF
#endif
/**
* @brief Should the content of the console be saved for redrawing.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
* @details If this feature is enabled, the contents of the console will be saved
* as it is written. If a redraw is required it will be redrawn from the
* history. Scrolling will also use the history buffer if it is turned on.
@@ -241,11 +241,11 @@
* @note @p gwinConsoleSetBuffer() can be used to turn the history buffer off and on.
*/
#ifndef GWIN_CONSOLE_USE_HISTORY
- #define GWIN_CONSOLE_USE_HISTORY FALSE
+ #define GWIN_CONSOLE_USE_HISTORY GFXOFF
#endif
/**
* @brief Use font width averaging for the history buffer allocation.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
* @details If this feature is enabled, the width one third of the way between
* the font's character width minimum and maximum will be used instead
* of the font's minimum width.
@@ -257,27 +257,27 @@
* with many characters in it.
*/
#ifndef GWIN_CONSOLE_HISTORY_AVERAGING
- #define GWIN_CONSOLE_HISTORY_AVERAGING FALSE
+ #define GWIN_CONSOLE_HISTORY_AVERAGING GFXOFF
#endif
/**
* @brief Should the history be turned on for all console windows when they are first created.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
* @note @p gwinConsoleSetBuffer() can be used to turn the history buffer off and on at
* any time.
*/
#ifndef GWIN_CONSOLE_HISTORY_ATCREATE
- #define GWIN_CONSOLE_HISTORY_ATCREATE FALSE
+ #define GWIN_CONSOLE_HISTORY_ATCREATE GFXOFF
#endif
/**
* @brief Console Windows need floating point support in @p gwinPrintf
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
*/
#ifndef GWIN_CONSOLE_USE_FLOAT
- #define GWIN_CONSOLE_USE_FLOAT FALSE
+ #define GWIN_CONSOLE_USE_FLOAT GFXOFF
#endif
/**
* @brief Console windows support escape sequences to control display
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
*
* @note
* Currently supported:
@@ -292,60 +292,60 @@
* ESC J Clear the window
*/
#ifndef GWIN_CONSOLE_ESCSEQ
- #define GWIN_CONSOLE_ESCSEQ FALSE
+ #define GWIN_CONSOLE_ESCSEQ GFXOFF
#endif
/**
* @brief Console Windows need BaseStreamSequential support (ChibiOS only)
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
* @note To use the ChibiOS basestream functions such as chprintf()
* for printing in a console window you need to set this option to
- * TRUE in your gfxconf.h and include in your application source file...
+ * GFXON in your gfxconf.h and include in your application source file...
* \#include "chprintf.h"
* In your makefile, as part of your list of C source files, include
* ${CHIBIOS}/os/various/chprintf.c
*/
#ifndef GWIN_CONSOLE_USE_BASESTREAM
- #define GWIN_CONSOLE_USE_BASESTREAM FALSE
+ #define GWIN_CONSOLE_USE_BASESTREAM GFXOFF
#endif
/**
* @brief Image windows can optionally support animated images
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
*/
#ifndef GWIN_NEED_IMAGE_ANIMATION
- #define GWIN_NEED_IMAGE_ANIMATION FALSE
+ #define GWIN_NEED_IMAGE_ANIMATION GFXOFF
#endif
/**
* @brief Enable the API to use attributes in the label widget
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
* @note Using this feature is discouraged. The proper (and faster as well
* as more efficient) way is to use two separate labels.
*/
#ifndef GWIN_LABEL_ATTRIBUTE
- #define GWIN_LABEL_ATTRIBUTE FALSE
+ #define GWIN_LABEL_ATTRIBUTE GFXOFF
#endif
/**
* @brief Enable the API to use images in items in the list widget
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
*/
#ifndef GWIN_NEED_LIST_IMAGES
- #define GWIN_NEED_LIST_IMAGES FALSE
+ #define GWIN_NEED_LIST_IMAGES GFXOFF
#endif
/**
* @brief Enable the API to automatically increment the progressbar over time
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
*/
#ifndef GWIN_PROGRESSBAR_AUTO
- #define GWIN_PROGRESSBAR_AUTO FALSE
+ #define GWIN_PROGRESSBAR_AUTO GFXOFF
#endif
/**
* @brief Should the slider avoid snapping to a fixed position when the mouse is released
- * @details Defaults to FALSE
- * @note If FALSE the slider will snap to the closest set-able position when the
- * mouse is released. If TRUE it will maintain the position the
+ * @details Defaults to GFXOFF
+ * @note If GFXOFF the slider will snap to the closest set-able position when the
+ * mouse is released. If GFXON it will maintain the position the
* mouse was released at, except when at the minimum and maximum slider values.
*/
#ifndef GWIN_SLIDER_NOSNAP
- #define GWIN_SLIDER_NOSNAP FALSE
+ #define GWIN_SLIDER_NOSNAP GFXOFF
#endif
/**
* @brief The number of pixels of dead-band at each end of the slider
@@ -374,11 +374,11 @@
#endif
/**
* @brief Should flashing of widgets be supported
- * @details Defaults to FALSE
- * @pre Requires GWIN_NEED_WINDOWMANAGER to be TRUE
+ * @details Defaults to GFXOFF
+ * @pre Requires GWIN_NEED_WINDOWMANAGER to be GFXON
*/
#ifndef GWIN_NEED_FLASHING
- #define GWIN_NEED_FLASHING FALSE
+ #define GWIN_NEED_FLASHING GFXOFF
#endif
/**
* @brief What is the period for the flashing timer
@@ -398,7 +398,7 @@
* @}
*
* @name GWIN Virtual Keyboard Layouts
- * @brief One or more of these may be defined. They will only be created if GWIN_NEED_KEYBOARD is TRUE.
+ * @brief One or more of these may be defined. They will only be created if GWIN_NEED_KEYBOARD is GFXON.
* @{
*/
/**
@@ -406,7 +406,7 @@
* @details Defaults to VirtualKeyboardLayout_English1
*/
#ifndef GWIN_NEED_KEYBOARD_ENGLISH1
- #define GWIN_NEED_KEYBOARD_ENGLISH1 TRUE
+ #define GWIN_NEED_KEYBOARD_ENGLISH1 GFXON
#endif
/** @} */
diff --git a/src/gwin/gwin_progressbar.h b/src/gwin/gwin_progressbar.h
index 1824a4e9..646f6954 100644
--- a/src/gwin/gwin_progressbar.h
+++ b/src/gwin/gwin_progressbar.h
@@ -14,8 +14,8 @@
*
* @brief ProgressBar widget.
*
- * @pre GFX_USE_GWIN must be set to TRUE in your gfxconf.h
- * @pre GWIN_NEED_PROGRESSBAR must be set to TRUE in your gfxconf.h
+ * @pre GFX_USE_GWIN must be set to GFXON in your gfxconf.h
+ * @pre GWIN_NEED_PROGRESSBAR must be set to GFXON in your gfxconf.h
* @{
*/
@@ -213,7 +213,7 @@ void gwinProgressbarDraw_Std(GWidgetObject *gw, void *param);
* and inactive areas. No checking is done to compare the dimensions of the progressbar
* to the size of the image. Note text is drawn on top of the image.
*
- * @pre GDISP_NEED_IMAGE must be set to TRUE
+ * @pre GDISP_NEED_IMAGE must be set to GFXON
*
* @api
*/
diff --git a/src/gwin/gwin_radio.h b/src/gwin/gwin_radio.h
index 3371a9ef..161cbb19 100644
--- a/src/gwin/gwin_radio.h
+++ b/src/gwin/gwin_radio.h
@@ -17,8 +17,8 @@
* @details RadioButtons need to be grouped together. This is archived by passing a group parameter through
* @p gwinRadioCreate().
*
- * @pre GFX_USE_GWIN must be set to TRUE in your gfxconf.h
- * @pre GWIN_NEED_RADIO must be set to TRUE in your gfxconf.h
+ * @pre GFX_USE_GWIN must be set to GFXON in your gfxconf.h
+ * @pre GWIN_NEED_RADIO must be set to GFXON in your gfxconf.h
* @{
*/
diff --git a/src/gwin/gwin_slider.h b/src/gwin/gwin_slider.h
index 29cbeea0..616663be 100644
--- a/src/gwin/gwin_slider.h
+++ b/src/gwin/gwin_slider.h
@@ -16,8 +16,8 @@
*
* @details Extended events can be enabled using @p gwinSliderSendExtendedEvents().
*
- * @pre GFX_USE_GWIN must be set to TRUE in your gfxconf.h
- * @pre GWIN_NEED_SLIDER must be set to TRUE in your gfxconf.h
+ * @pre GFX_USE_GWIN must be set to GFXON in your gfxconf.h
+ * @pre GWIN_NEED_SLIDER must be set to GFXON in your gfxconf.h
* @{
*/
@@ -191,7 +191,7 @@ void gwinSliderDraw_Std(GWidgetObject *gw, void *param);
* No checking is done to compare the size of the button to the size of the image.
* No text is drawn on top of the image.
*
- * @pre GDISP_NEED_IMAGE must be set to TRUE
+ * @pre GDISP_NEED_IMAGE must be set to GFXON
*
* @api
*/
diff --git a/src/gwin/gwin_tabset.h b/src/gwin/gwin_tabset.h
index 6eaeb014..90d9eb3b 100644
--- a/src/gwin/gwin_tabset.h
+++ b/src/gwin/gwin_tabset.h
@@ -18,8 +18,8 @@
* Note: Although the tabset is implemented as a container - you don't put your controls
* directly on the tabset. Instead you create a page and put your widgets on the page.
*
- * @pre GFX_USE_GWIN must be set to TRUE in your gfxconf.h
- * @pre GWIN_NEED_TABSET must be set to TRUE in your gfxconf.h
+ * @pre GFX_USE_GWIN must be set to GFXON in your gfxconf.h
+ * @pre GWIN_NEED_TABSET must be set to GFXON in your gfxconf.h
* @{
*/
@@ -224,7 +224,7 @@ void gwinTabsetDraw_Transparent(GWidgetObject *gw, void *param);
* @note The image must be already opened before calling @p gwinSetCustomDraw(). The handle is passed as the parameter
* to this function.
*
- * @pre GDISP_NEED_IMAGE must be set to TRUE
+ * @pre GDISP_NEED_IMAGE must be set to GFXON
*
* @api
*/
diff --git a/src/gwin/gwin_textedit.h b/src/gwin/gwin_textedit.h
index 8cf6c03e..0fdcc843 100644
--- a/src/gwin/gwin_textedit.h
+++ b/src/gwin/gwin_textedit.h
@@ -17,10 +17,10 @@
* @note Due to the modularity of the @p GINPUT module, the text input can either come from a real physical
* keyboard or from a vritual on-screen keyboard such as the @p KeyboardWidget.
*
- * @pre GFX_USE_GDISP must be set to TRUE in your gfxconf.h
- * @pre GFX_USE_GWIN must be set to TRUE in your gfxconf.h
- * @pre GDISP_NEED_TEXT must be set to TRUE in your gfxconf.h
- * @pre GWIN_NEED_TEXTEDIT must be set to TRUE in your gfxconf.h
+ * @pre GFX_USE_GDISP must be set to GFXON in your gfxconf.h
+ * @pre GFX_USE_GWIN must be set to GFXON in your gfxconf.h
+ * @pre GDISP_NEED_TEXT must be set to GFXON in your gfxconf.h
+ * @pre GWIN_NEED_TEXTEDIT must be set to GFXON in your gfxconf.h
* @pre The fonts you want to use must be enabled in your gfxconf.h
*
* @{
diff --git a/src/gwin/gwin_widget.h b/src/gwin/gwin_widget.h
index ce7490cd..58c71b16 100644
--- a/src/gwin/gwin_widget.h
+++ b/src/gwin/gwin_widget.h
@@ -18,7 +18,7 @@
* via an input device such as a mouse or toggle buttons. It is the
* base class for widgets such as buttons and sliders.
*
- * @pre GFX_USE_GWIN and GWIN_NEED_WIDGET must be set to TRUE in your gfxconf.h
+ * @pre GFX_USE_GWIN and GWIN_NEED_WIDGET must be set to GFXON in your gfxconf.h
* @{
*/
@@ -234,7 +234,7 @@ const char *gwinGetText(GHandle gh);
#if (GFX_USE_GFILE && GFILE_NEED_PRINTG && GFILE_NEED_STRINGS) || defined(__DOXYGEN__)
/**
* @brief Set the text of a widget using a printf style format.
- * @pre GFX_USE_GFILE, GFILE_NEED_PRINTG and GFILE_NEED_STRINGS must all be TRUE
+ * @pre GFX_USE_GFILE, GFILE_NEED_PRINTG and GFILE_NEED_STRINGS must all be GFXON
*
* @param[in] gh The widget handle
* @param[in] fmt The format string using a printf/g syntax. See @p vsnprintg()
@@ -269,7 +269,7 @@ bool_t gwinIsWidget(GHandle gh);
*
* @note Non-widgets will ignore this call.
*
- * @pre Requires GWIN_WIDGET_TAGS to be TRUE
+ * @pre Requires GWIN_WIDGET_TAGS to be GFXON
*
* @api
*/
@@ -281,7 +281,7 @@ bool_t gwinIsWidget(GHandle gh);
*
* @param[in] gh The widget handle
*
- * @pre Requires GWIN_WIDGET_TAGS to be TRUE
+ * @pre Requires GWIN_WIDGET_TAGS to be GFXON
*
* @api
*/
diff --git a/src/gwin/gwin_rules.h b/src/gwin/gwin_rules.h
index c044be66..08e2e8f0 100644
--- a/src/gwin/gwin_rules.h
+++ b/src/gwin/gwin_rules.h
@@ -19,14 +19,14 @@
#if GFX_USE_GWIN
// Sub-system rules
#if !GFX_USE_GDISP
#error "GWIN: GFX_USE_GDISP must be TRUE when using GWIN"
#endif
#if !GDISP_NEED_CLIP
#if GFX_DISPLAY_RULE_WARNINGS
#if GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_DIRECT
#warning "GWIN: Drawing can occur outside the defined windows as GDISP_NEED_CLIP is FALSE"
#elif GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_MACRO
- COMPILER_WARNING("GWIN: Drawing can occur outside the defined windows as GDISP_NEED_CLIP is FALSE")
+ COMPILER_WARNING("GWIN: Drawing can occur outside the defined windows as GDISP_NEED_CLIP is GFXOFF")
#endif
#endif
#endif
@@ -42,7 +42,7 @@
#endif
#endif
#undef GWIN_NEED_CONTAINERS
- #define GWIN_NEED_CONTAINERS TRUE
+ #define GWIN_NEED_CONTAINERS GFXON
#endif
#endif
#if GWIN_NEED_BUTTON || GWIN_NEED_SLIDER || GWIN_NEED_CHECKBOX || GWIN_NEED_LABEL || GWIN_NEED_RADIO || GWIN_NEED_LIST || \
@@ -56,7 +56,7 @@
#endif
#endif
#undef GWIN_NEED_WIDGET
- #define GWIN_NEED_WIDGET TRUE
+ #define GWIN_NEED_WIDGET GFXON
#endif
#endif
@@ -71,100 +71,100 @@
#endif
#endif
#undef GWIN_NEED_WIDGET
- #define GWIN_NEED_WIDGET TRUE
+ #define GWIN_NEED_WIDGET GFXON
#endif
#endif
#if GWIN_NEED_WIDGET
#if !GDISP_NEED_TEXT
#error "GWIN: GDISP_NEED_TEXT is required if GWIN_NEED_WIDGET is TRUE."
#endif
#if !GFX_USE_GINPUT
// This test also ensures that GFX_USE_GEVENT is set
#error "GWIN: GFX_USE_GINPUT is required if GWIN_NEED_WIDGET is TRUE"
#endif
#if !GWIN_NEED_WINDOWMANAGER
#if GFX_DISPLAY_RULE_WARNINGS
#if GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_DIRECT
#warning "GWIN: GWIN_NEED_WINDOWMANAGER is required if GWIN_NEED_WIDGET is TRUE. It has been turned on for you."
#elif GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_MACRO
- COMPILER_WARNING("GWIN: GWIN_NEED_WINDOWMANAGER is required if GWIN_NEED_WIDGET is TRUE. It has been turned on for you.")
+ COMPILER_WARNING("GWIN: GWIN_NEED_WINDOWMANAGER is required if GWIN_NEED_WIDGET is GFXON. It has been turned on for you.")
#endif
#endif
#undef GWIN_NEED_WINDOWMANAGER
- #define GWIN_NEED_WINDOWMANAGER TRUE
+ #define GWIN_NEED_WINDOWMANAGER GFXON
#endif
#if !GDISP_NEED_MULTITHREAD
#if GFX_DISPLAY_RULE_WARNINGS
#if GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_DIRECT
#warning "GWIN: GDISP_NEED_MULTITHREAD is required if GWIN_NEED_WIDGET is TRUE. It has been turned on for you"
#elif GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_MACRO
- COMPILER_WARNING("GWIN: GDISP_NEED_MULTITHREAD is required if GWIN_NEED_WIDGET is TRUE. It has been turned on for you")
+ COMPILER_WARNING("GWIN: GDISP_NEED_MULTITHREAD is required if GWIN_NEED_WIDGET is GFXON. It has been turned on for you")
#endif
#endif
#undef GDISP_NEED_MULTITHREAD
- #define GDISP_NEED_MULTITHREAD TRUE
+ #define GDISP_NEED_MULTITHREAD GFXON
#endif
#endif
#if GWIN_NEED_WINDOWMANAGER
#if !GFX_USE_GQUEUE || !GQUEUE_NEED_ASYNC
#if GFX_DISPLAY_RULE_WARNINGS
#if GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_DIRECT
#warning "GWIN: GFX_USE_GQUEUE and GQUEUE_NEED_ASYNC is required if GWIN_NEED_WINDOWMANAGER is TRUE. It has been turned on for you."
#elif GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_MACRO
- COMPILER_WARNING("GWIN: GFX_USE_GQUEUE and GQUEUE_NEED_ASYNC is required if GWIN_NEED_WINDOWMANAGER is TRUE. It has been turned on for you.")
+ COMPILER_WARNING("GWIN: GFX_USE_GQUEUE and GQUEUE_NEED_ASYNC is required if GWIN_NEED_WINDOWMANAGER is GFXON. It has been turned on for you.")
#endif
#endif
#undef GFX_USE_GQUEUE
#undef GQUEUE_NEED_ASYNC
- #define GFX_USE_GQUEUE TRUE
- #define GQUEUE_NEED_ASYNC TRUE
+ #define GFX_USE_GQUEUE GFXON
+ #define GQUEUE_NEED_ASYNC GFXON
#endif
#if !GFX_USE_GTIMER
#if GFX_DISPLAY_RULE_WARNINGS
#if GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_DIRECT
#warning "GWIN: GFX_USE_GTIMER is required if GWIN_NEED_WINDOWMANAGER is TRUE. It has been turned on for you."
#elif GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_MACRO
- COMPILER_WARNING("GWIN: GFX_USE_GTIMER is required if GWIN_NEED_WINDOWMANAGER is TRUE. It has been turned on for you.")
+ COMPILER_WARNING("GWIN: GFX_USE_GTIMER is required if GWIN_NEED_WINDOWMANAGER is GFXON. It has been turned on for you.")
#endif
#endif
#undef GFX_USE_GTIMER
- #define GFX_USE_GTIMER TRUE
+ #define GFX_USE_GTIMER GFXON
#endif
#endif
// Rules for individual objects
#if GWIN_NEED_LIST
#if !GDISP_NEED_TEXT
#error "GWIN: GDISP_NEED_TEXT is required when GWIN_NEED_LIST is TRUE."
#endif
#endif
#if GWIN_NEED_RADIO
#if !GDISP_NEED_CIRCLE
#if GFX_DISPLAY_RULE_WARNINGS
#if GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_DIRECT
#warning "GWIN: GDISP_NEED_CIRCLE should be set to TRUE for much nicer radio button widgets."
#elif GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_MACRO
- COMPILER_WARNING("GWIN: GDISP_NEED_CIRCLE should be set to TRUE for much nicer radio button widgets.")
+ COMPILER_WARNING("GWIN: GDISP_NEED_CIRCLE should be set to GFXON for much nicer radio button widgets.")
#endif
#endif
#endif
#endif
#if GWIN_NEED_IMAGE
#if !GDISP_NEED_IMAGE
#error "GWIN: GDISP_NEED_IMAGE is required when GWIN_NEED_IMAGE is TRUE."
#endif
#endif
#if GWIN_NEED_CONSOLE
#if !GDISP_NEED_TEXT
#error "GWIN: GDISP_NEED_TEXT is required if GWIN_NEED_CONSOLE is TRUE."
#endif
#endif
#if GWIN_NEED_TEXTEDIT
#if !GDISP_NEED_TEXT
#error "GWIN: GDISP_NEED_TEXT is required if GWIN_NEED_TEXTEDIT is TRUE."
#endif
#if !(GINPUT_NEED_KEYBOARD || GWIN_NEED_KEYBOARD)
#error "GWIN: GINPUT_NEED_KEYBOARD or GWIN_NEED_KEYBOARD is required if GWIN_NEED_TEXTEDIT is TRUE."
#endif
#endif
#endif
@@ -19,14 +19,14 @@
// Sub-system rules
#if !GFX_USE_GDISP
- #error "GWIN: GFX_USE_GDISP must be TRUE when using GWIN"
+ #error "GWIN: GFX_USE_GDISP must be GFXON when using GWIN"
#endif
#if !GDISP_NEED_CLIP
@@ -19,14 +19,14 @@
#if GFX_DISPLAY_RULE_WARNINGS
#if GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_DIRECT
- #warning "GWIN: Drawing can occur outside the defined windows as GDISP_NEED_CLIP is FALSE"
+ #warning "GWIN: Drawing can occur outside the defined windows as GDISP_NEED_CLIP is GFXOFF"
#elif GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_MACRO
@@ -71,100 +71,100 @@
#if GWIN_NEED_WIDGET
#if !GDISP_NEED_TEXT
- #error "GWIN: GDISP_NEED_TEXT is required if GWIN_NEED_WIDGET is TRUE."
+ #error "GWIN: GDISP_NEED_TEXT is required if GWIN_NEED_WIDGET is GFXON."
#endif
#if !GFX_USE_GINPUT
@@ -71,100 +71,100 @@
#if !GFX_USE_GINPUT
// This test also ensures that GFX_USE_GEVENT is set
- #error "GWIN: GFX_USE_GINPUT is required if GWIN_NEED_WIDGET is TRUE"
+ #error "GWIN: GFX_USE_GINPUT is required if GWIN_NEED_WIDGET is GFXON"
#endif
#if !GWIN_NEED_WINDOWMANAGER
@@ -71,100 +71,100 @@
#if GFX_DISPLAY_RULE_WARNINGS
#if GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_DIRECT
- #warning "GWIN: GWIN_NEED_WINDOWMANAGER is required if GWIN_NEED_WIDGET is TRUE. It has been turned on for you."
+ #warning "GWIN: GWIN_NEED_WINDOWMANAGER is required if GWIN_NEED_WIDGET is GFXON. It has been turned on for you."
#elif GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_MACRO
@@ -71,100 +71,100 @@
#if GFX_DISPLAY_RULE_WARNINGS
#if GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_DIRECT
- #warning "GWIN: GDISP_NEED_MULTITHREAD is required if GWIN_NEED_WIDGET is TRUE. It has been turned on for you"
+ #warning "GWIN: GDISP_NEED_MULTITHREAD is required if GWIN_NEED_WIDGET is GFXON. It has been turned on for you"
#elif GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_MACRO
@@ -71,100 +71,100 @@
#if GFX_DISPLAY_RULE_WARNINGS
#if GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_DIRECT
- #warning "GWIN: GFX_USE_GQUEUE and GQUEUE_NEED_ASYNC is required if GWIN_NEED_WINDOWMANAGER is TRUE. It has been turned on for you."
+ #warning "GWIN: GFX_USE_GQUEUE and GQUEUE_NEED_ASYNC is required if GWIN_NEED_WINDOWMANAGER is GFXON. It has been turned on for you."
#elif GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_MACRO
@@ -71,100 +71,100 @@
#if GFX_DISPLAY_RULE_WARNINGS
#if GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_DIRECT
- #warning "GWIN: GFX_USE_GTIMER is required if GWIN_NEED_WINDOWMANAGER is TRUE. It has been turned on for you."
+ #warning "GWIN: GFX_USE_GTIMER is required if GWIN_NEED_WINDOWMANAGER is GFXON. It has been turned on for you."
#elif GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_MACRO
@@ -71,100 +71,100 @@
#if GWIN_NEED_LIST
#if !GDISP_NEED_TEXT
- #error "GWIN: GDISP_NEED_TEXT is required when GWIN_NEED_LIST is TRUE."
+ #error "GWIN: GDISP_NEED_TEXT is required when GWIN_NEED_LIST is GFXON."
#endif
#endif
@@ -71,100 +71,100 @@
#if GFX_DISPLAY_RULE_WARNINGS
#if GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_DIRECT
- #warning "GWIN: GDISP_NEED_CIRCLE should be set to TRUE for much nicer radio button widgets."
+ #warning "GWIN: GDISP_NEED_CIRCLE should be set to GFXON for much nicer radio button widgets."
#elif GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_MACRO
@@ -71,100 +71,100 @@
#if GWIN_NEED_IMAGE
#if !GDISP_NEED_IMAGE
- #error "GWIN: GDISP_NEED_IMAGE is required when GWIN_NEED_IMAGE is TRUE."
+ #error "GWIN: GDISP_NEED_IMAGE is required when GWIN_NEED_IMAGE is GFXON."
#endif
#endif
@@ -71,100 +71,100 @@
#if GWIN_NEED_CONSOLE
#if !GDISP_NEED_TEXT
- #error "GWIN: GDISP_NEED_TEXT is required if GWIN_NEED_CONSOLE is TRUE."
+ #error "GWIN: GDISP_NEED_TEXT is required if GWIN_NEED_CONSOLE is GFXON."
#endif
#endif
@@ -71,100 +71,100 @@
#if GWIN_NEED_TEXTEDIT
#if !GDISP_NEED_TEXT
- #error "GWIN: GDISP_NEED_TEXT is required if GWIN_NEED_TEXTEDIT is TRUE."
+ #error "GWIN: GDISP_NEED_TEXT is required if GWIN_NEED_TEXTEDIT is GFXON."
#endif
#if !(GINPUT_NEED_KEYBOARD || GWIN_NEED_KEYBOARD)
@@ -71,100 +71,100 @@
#endif
#if !(GINPUT_NEED_KEYBOARD || GWIN_NEED_KEYBOARD)
- #error "GWIN: GINPUT_NEED_KEYBOARD or GWIN_NEED_KEYBOARD is required if GWIN_NEED_TEXTEDIT is TRUE."
+ #error "GWIN: GINPUT_NEED_KEYBOARD or GWIN_NEED_KEYBOARD is required if GWIN_NEED_TEXTEDIT is GFXON."
#endif
#endif